@@ -66,11 +66,6 @@ class Dns:
         domain_config = self.domain_config.load()
         return 'device.{}.{}'.format(domain_config.user_domain, self.main_domain_name)
 
-    def service_urls(self, name):
-        service = self.get_service(name)
-        mapping = self.port_mapper.get(service.port)
-        return ServiceUrls(self.full_name(), service, mapping)
-
     def service_info(self, name):
         service = self.get_service(name)
         if not service:
